; --------------------------------------------------------
; | FILE    : mark_3.asm                                 |
; | PROJECT : Low Cost PC Based Oscilloscope             |
; | DESC    : Sends squarewave using real-time frames    |
; | ==================================================== |
; | DATE    : 13/02/2002                                 |
; | BY      : Colin K McCord                             |
; | VERSION : 1.0                                        |
; --------------------------------------------------------			

					#include <p16f877.inc>	; Using PIC16F877

	org 0x0000				; Reset Vector
	goto MAIN	

	org 0x0020				; Start of program

	; Include RS232 Subroutines (INITCOMS, PUTCHAR, GETCHAR)
	#include "rs232.asm"	

COUNT		equ		23h	; Loop Control Register


MAIN
	call INITCOMS		; Initialise RS232 Communications
	

	; Squarewave __________----------__________ -5V to +5V
	; -5V = 0d = 0000000000b, +5V = 1024d = 1111111111b
	

	; Real-Time Frames Structure 
	; -------------------------   -------------------------
	; |A |B |C |d9|d8|d7|d6|d5|   |A |B |C |d4|d3|d2|d1|d0|
	; -------------------------   -------------------------
	; A = 0, for byte 1 (d9 to d5), A = 1 for byte 2 (d4 to d0)
	; BC = 00 for CH1, BC = 01 for CH2, BC = 10 for CH3, BC = 11 for CH4

SQUAREWAVE

	movlw   .15			; Set counter to 15dec
	movwf	COUNT

L1	; Loop 1, Low point of squarewave
	
	; Byte 1
	movlw   b'00000000'	; A=0, B=0, C=0, etc...
	movwf	DATA_TX		
	call 	PUTCHAR

	; Byte 2
	movlw   b'10000000'	; A=1, B=0, C=0, etc...
	movwf	DATA_TX		
	call 	PUTCHAR

	movf	COUNT,w		; Move counter into working register
	addlw	-.1			; Dec COUNTer
	movwf   COUNT		; Update COUNTer
	btfsc	STATUS,C	; Check the Carry/Not borrow flag. Skip if borrow	
	goto 	L1			; Loop 15-times


	movlw   .15			; Set counter to 15dec
	movwf	COUNT

L2  ; Loop 2, High point of squarewave

	; Byte 1
	movlw   b'00011111'	; A=0, B=0, C=0, etc...
	movwf	DATA_TX		
	call 	PUTCHAR

	; Byte 2
	movlw   b'10011111'	; A=1, B=0, C=0, etc...
	movwf	DATA_TX		
	call 	PUTCHAR

	movf	COUNT,w		; Move counter into working register
	addlw	-.1			; Dec COUNTer
	movwf   COUNT		; Update COUNTer
	btfsc	STATUS,C	; Check the Carry/Not borrow flag. Skip if borrow	
	goto 	L2			; Loop 15-times


	goto SQUAREWAVE		; Repeat forever

	END

