; --------------------------------------------------------
; | FILE    : adc.asm                                    |
; | PROJECT : Low Cost PC Based Oscilloscope             |
; | DESC    : ADC subroutines                            |
; | ==================================================== |
; | DATE    : 13/02/2002                                 |
; | BY      : Colin K McCord                             |
; | VERSION : 1.0                                        |
; --------------------------------------------------------

ADC_HI	equ 24h
ADC_LO	equ 25h


; --------------------------------------------------------
; | FUNCTION: Initialises ADC                            |
; | RESOURCE: PIC ADC                                    |
; | ENTRY   : None                                       |
; | EXIT    : ADC Initialised. RA4-RA0, RC osc, Ch1      |
; | ==================================================== |
; | DATE    : 13/02/2002                                 |
; | BY      : Colin K McCord                             |
; | VERSION : 1.0                                        |
; --------------------------------------------------------

INIT_ADC

	; Setup ADCON1 Register
	bsf	STATUS,RP0		; Select Bank 1.
	movlw	b'10000010'		; Select RA4-RA0 as analog inputs, RE0-RE2 digital
	movwf	ADCON1			; and Select A/D result format, Right Justified.

	; Setup ADCON0 Register
	bcf	STATUS,RP0		; Select Bank 0.
	movlw	b'11000001'		; Select, RC osc, ch0 and turn on ADC.
	movwf	ADCON0

	return



; --------------------------------------------------------
; | MACRO   : K us delay                                 |
; | ENTRY   : K delay value, XTAL Clock Speed            |
; | EXIT    : Waits k microseconds                       |
; | ==================================================== |
; | DATE    : 13/02/2002                                 |
; | BY      : Colin K McCord                             |
; | VERSION : 1.0                                        |
; --------------------------------------------------------
DelayUS macro	K
					; K is the number of us delay.
	local	 DELAY_US_LOOP	
	movlw 	(K*XTAL)/(4*3)+1	; 1~ 

DELAY_US_LOOP

	addlw	-1			; Decrement count: N~
	btfss 	STATUS,Z		; to zero		 : N + 1~
	goto	DELAY_US_LOOP
	endm



; --------------------------------------------------------
; | FUNCTION: Reads ADC                                  |
; | RESOURCE: PIC ADC                                    |
; | ENTRY   : None                                       |
; | EXIT    : ADC Value in ADC_HI and ADC_LO             |
; | ==================================================== |
; | DATE    : 13/02/2002                                 |
; | BY      : Colin K McCord                             |
; | VERSION : 1.0                                        |
; --------------------------------------------------------

READ_ADC

	DelayUS 20			; Provide necessary sampling time.
	bsf	ADCON0,GO		; Start new A/D conversion.

READ_ADC_LOOP

	btfsc	ADCON0,GO		; A/D over?
	goto	READ_ADC_LOOP		; no then loop.

	; Yes then get A/D value
	bsf	STATUS,RP0		; Select Bank 1.
	movf	ADRESL,w		; Get A/D Low Byte.
	movwf	ADC_LO			; Move to ADC_LO File.

	bcf	STATUS,RP0		; Select Bank 0.	
	movf	ADRESH,w		; Get A/D High Byte.
	movwf	ADC_HI			; Move to ADC_HI File.

	return


