/* --------------------------------------------------------
   | FILE    : mark_c3.c                                  |
   | PROJECT : Low Cost PC Based Oscilloscope             |
   | DESC    : Read CH1 ADC, transmit result through      |
   |         : RS232 using the real-time frame format.    |          
   | ==================================================== |
   | DATE    : 19/02/2002                                 |
   | BY      : Colin K McCord                             |
   | VERSION : 1.1                                        |
   -------------------------------------------------------- */


#include <16F877.h>
#device PIC16F877 *=16 ADC=10

// use #device adc = 10 to implement a 10-bit conversion, 
// otherwise the default is 8-bits.


#fuses HS,NOWDT,NOPROTECT,NOLVP
#use delay(clock = 4000000)
#use rs232(baud=9600, xmit = PIN_C6, rcv = PIN_C7, parity = N, bits = 8)


main()
{
	// NOTE: by default in CCS all var's are unsigned
	long int adcValue; 		// 16-bit storage for ADC reading
	char adcHI,adcLO;		// 8-bit storage for real-time frames.

	setup_adc_ports(A_ANALOG);	// RA0 - RA4 Analog, RE0 - RE2 digital
	setup_adc(ADC_CLOCK_INTERNAL);	// Use internal ADC clock.
	set_adc_channel(0);
	
	delay_us(20);	// Delay for sampling cap to charge 

	while(TRUE)
	{
		adcValue = read_adc();	// Get ADC reading

		/* Convert 16-bit adcValue to Real-time frame structure, CH1 */
		adcHI = (char)((adcValue >> 5)& 0x1f);	// 0|0|0|d9|d8|d7|d6|d5
		adcLO = (char)((adcValue & 0x1f)|0x80);	// 1|0|0|d4|d3|d2|d1|d0
			
		putc(adcHI);	// Transmit Byte 1 (d9...d5)
		putc(adcLO);	// Transmit Byte 2 (d4...d0)

		delay_ms(10);	// Preset delay, repeat every 10ms
	}
}
