/* --------------------------------------------------------
   | FILE    : mark_c4.c                                  |
   | PROJECT : Low Cost PC Based Oscilloscope             |
   | DESC    : Test RS232, baud rate set by dip switches. |
   | ==================================================== |
   | DATE    : 01/03/2002                                 |
   | BY      : Colin K McCord                             |
   | VERSION : 1.0                                        |
   -------------------------------------------------------- */


#include <16F877.h>
#device PIC16F877 *=16 ADC=10

#fuses HS,NOWDT,NOPROTECT,NOLVP

#byte 	PORTE = 0x09	// PortE lives in File 9

/* Note 20MHz clock must be used for 115,000 bps, the % error is to large at slower speeds */
#use delay(clock = 20000000)	// 20MHz clock, change this value if using different clock speed.
#use rs232(baud=9600, xmit = PIN_C6, rcv = PIN_C7, parity = N, bits = 8)


#use	fast_io(E)		// Fast access to PortE (don't fiddle with TRISE)

/* Forward declaration of functions */
void SetBaudRate();


main()
{
	set_tris_e(0x17);	// TRISE = 00010111; RE2,RE1 and RE0 TTL Inputs


	SetBaudRate();

	while(TRUE)
	{	
		/* Note prinf could be used but this fuction is wasteful and will not be used */
		putc('T');	// Transmit T
		putc('e');	// Transmit e
		putc('s');	// Transmit s
		putc('t');	// Transmit t
		putc('i');	// Transmit i
		putc('n');	// Transmit n
		putc('g');	// Transmit g
		putc('.');	// Transmit .
		putc('.');	// Transmit .
		putc('.');	// Transmit .

		delay_ms(1000);	// Present delay, repeat every second
	}
}

void SetBaudRate()
{
	switch(PORTE & 0x07)	// Read dip switches and setup baud rate
	{
		case 0: set_uart_speed(4800);   break;
		case 1: set_uart_speed(9600);   break;
		case 2: set_uart_speed(14400);  break;
		case 3:	set_uart_speed(19200);	break;
		case 4: set_uart_speed(32768);  break;
		case 5: set_uart_speed(38400);  break;
		case 6: set_uart_speed(57600);  break;
		case 7: set_uart_speed(115200); break;
	}
}
